<?php
/**
 * functions and definitions
 *
 * @package We Build
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 1170; /* pixels */
}

if ( ! function_exists( 'we_build_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function we_build_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 */
	load_theme_textdomain( 'we-build', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

    // Setup the WordPress core custom logo feature.

    add_theme_support( 'custom-logo');

    add_theme_support( 'title-tag' );
        
    //Add callback for custom TinyMCE editor stylesheets.

   	add_editor_style( 'editor-style.css' );


	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'we-build' )		
	) );

	// Enable support for Post Formats.
	add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );

	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'we_build_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif; // we_build_setup
add_action( 'after_setup_theme', 'we_build_setup' );

/**
 * Register widgetized area and update sidebar with default widgets.
 */
function we_build_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'we-build' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
   
    register_sidebar(array(
    	'id' => 'footer-widget-1',
    	'name' =>  __( 'Footer Widget 1', 'we-build' ),
    	'description' =>  __( 'Used for footer widget area', 'we-build' ),
    	'before_widget' => '<div id="%1$s" class="widget %2$s">',
    	'after_widget' => '</div>',
    	'before_title' => '<h3 class="widgettitle">',
    	'after_title' => '</h3>',
    ));

    register_sidebar(array(
      'id' => 'footer-widget-2',
      'name' =>  __( 'Footer Widget 2', 'we-build' ),
      'description' =>  __( 'Used for footer widget area', 'we-build' ),
      'before_widget' => '<div id="%1$s" class="widget %2$s">',
      'after_widget' => '</div>',
      'before_title' => '<h3 class="widgettitle">',
      'after_title' => '</h3>',
    ));

    register_sidebar(array(
      'id' => 'footer-widget-3',
      'name' =>  __( 'Footer Widget 3', 'we-build' ),
      'description' =>  __( 'Used for footer widget area', 'we-build' ),
      'before_widget' => '<div id="%1$s" class="widget %2$s">',
      'after_widget' => '</div>',
      'before_title' => '<h3 class="widgettitle">',
      'after_title' => '</h3>',
    ));	
}
add_action( 'widgets_init', 'we_build_widgets_init' );


/**
 * adding the we build search form (created in extra.php)
 */

add_filter( 'get_search_form', 'we_build_wpsearch' );

if ( ! function_exists( 'we_build_fonts_url' ) ) {
	/**
	 * Register Google fonts.
	 *
	 * @return string Google fonts URL for the theme.
	 */
	function we_build_fonts_url() {
		$fonts_url = '';
		$fonts     = array();
		$subsets   = 'latin,latin-ext';

		/* translators: If there are characters in your language that are not supported by Montserrat, translate this to 'off'. Do not translate into your own language. */
		if ( 'off' !== _x( 'on', 'Montserrat', 'we-build' ) ) {
			$fonts[] = 'Montserrat:400,700';
		}		

		if ( $fonts ) {
			$fonts_url = add_query_arg( array(
				'family' => urlencode( implode( '|', $fonts ) ),
				'subset' => urlencode( $subsets ),
			), 'https://fonts.googleapis.com/css' );
		}

		return $fonts_url;
	}
}

/**
 * Enqueue scripts and styles. 
 */
function we_build_scripts() {

    wp_enqueue_style( 'we-build-bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css' );

    wp_enqueue_style( 'we-build-icons', get_template_directory_uri().'/assets/css/font-awesome.min.css' );  

	wp_enqueue_style( 'we-build-style', get_stylesheet_uri() );

	wp_enqueue_style( 'we-build-fonts', we_build_fonts_url(), array(), null );

	wp_enqueue_script( 'stickymenu', get_template_directory_uri() . '/assets/js/jquery.sticky.js', array('jquery') );
	wp_enqueue_script('we-build-bootstrapjs', get_template_directory_uri().'/assets/js/bootstrap.min.js', array('jquery') );
	
	wp_enqueue_script( 'we-build-bootstrapwp', get_template_directory_uri() . '/assets/js/functions.min.js', array('jquery') );	
	if( ( is_home() || is_front_page() ) && (get_theme_mod('slider_show', 1) == 1) ) {		
		wp_enqueue_script( 'we-build-mordernizer', get_template_directory_uri() . '/assets/js/modernizr.custom.28468.js', array('jquery'), true );
	}		

	wp_enqueue_script( 'we-build-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), '20170622', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'we_build_scripts' );


//=============================================================
// Function limit the number of words.
//=============================================================

function we_build_limit_words($string, $word_limit) {
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit) {
		if(count($words) > $word_limit) {
			array_pop($words);
			return implode(' ', $words).'...';	
		}
	} else {  
		return $string;
	}
}

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Load custom nav walker
 */

require get_template_directory() . '/inc/navwalker.php';
