<?php
/**
 * Theme Customizer
 *
 * @package We Build
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function we_build_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

    //more color customization

	$wp_customize->add_setting('site_main_color_scheme', array(
		'default' => '#ff7761',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'site_main_color_scheme',array(
			'label' => __('Main Color','we-build'),
			'section' => 'colors',
			'settings' => 'site_main_color_scheme'
		))
	);

	// Header Section Start		
	$wp_customize->add_section(
        'header_section',
        array(
            'title' => __('Header Setting', 'we-build'),
            'priority' => null,
			'description'	=> __('Customize the Header','we-build')
        )
    );	

	$wp_customize->add_setting('header_phone', array(
		'sanitize_callback'	=> 'we_build_sanitize_integer'
	));
	
	$wp_customize->add_control('header_phone',array(
    'label' => __('Phone Number','we-build'),
    'section'   => 'header_section',
    'type'      => 'text'
    ));

    $wp_customize->add_setting('header_address', array(
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('header_address',array(
    'label' => __('Address','we-build'),
    'section'   => 'header_section',
    'type'      => 'text'
    ));
    // Header Section End		


	// Social Section Start		
	$wp_customize->add_section(
        'social_section',
        array(
            'title' => __('Social Media Setting', 'we-build'),
            'priority' => null,
			'description'	=> __('Customize the Social Links','we-build')
        )
    );

    $wp_customize->add_setting('social_facebook', array(
		'sanitize_callback'	=> 'esc_url'
	));
	
	$wp_customize->add_control('social_facebook',array(
    'label' => __('Facebook Link','we-build'),
    'section'   => 'social_section',
    'type'      => 'text'
    ));
    $wp_customize->add_setting('social_twitter', array(
		'sanitize_callback'	=> 'esc_url'
	));
	
	$wp_customize->add_control('social_twitter',array(
    'label' => __('Twitter Link','we-build'),
    'section'   => 'social_section',
    'type'      => 'text'
    ));
    $wp_customize->add_setting('social_googleplus', array(
		'sanitize_callback'	=> 'esc_url'
	));
	
	$wp_customize->add_control('social_googleplus',array(
    'label' => __('Google plus Link','we-build'),
    'section'   => 'social_section',
    'type'      => 'text'
    ));

    $wp_customize->add_setting('social_youtube', array(
		'sanitize_callback'	=> 'esc_url'
	));
	
	$wp_customize->add_control('social_youtube',array(
    'label' => __('Youtube Link','we-build'),
    'section'   => 'social_section',
    'type'      => 'text'
    ));

    $wp_customize->add_setting('social_icon_color_scheme', array(
		'default' => '#ffffff',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'social_icon_color_scheme',array(
			'label' => __('Social Icon Color','we-build'),
			'section' => 'social_section',
			'settings' => 'social_icon_color_scheme'
		))
	);

	$wp_customize->add_setting('social_icon_link_color_scheme', array(
		'default' => '#fff',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'social_icon_link_color_scheme',array(
			'label' => __('Social Icon:hover Color','we-build'),
			'section' => 'social_section',
			'settings' => 'social_icon_link_color_scheme'
		))
	);
    // Social Section End		

    // Slider Section Start		
	$wp_customize->add_section(
        'slider_section',
        array(
            'title' => __('Slider Settings', 'we-build'),
            'priority' => null,
			'description'	=> __('Home Page Slider Settings','we-build')
        )
    );

    $wp_customize->add_setting( 'slider_show', array(
            'default' => 1,
			'sanitize_callback' => 'sanitize_text_field',
			'capability' => 'edit_theme_options',
    ));
    $wp_customize->add_control(
			'slider_show',array(
			    'section'   => 'slider_section',
			    'label'     => __('Check if you want to enable slider', 'we-build'),
			    'type'      => 'checkbox'
			    )
    );
    $wp_customize->add_setting('number_of_slides', array(
		'default' => '3',
		'sanitize_callback'	=> 'we_build_sanitize_integer'
	));
	$wp_customize->add_control('number_of_slides',array(
	    'label' => __('Number of slide items','we-build'),
	    'section'   => 'slider_section',
	    'type'      => 'text'
    ));

    $wp_customize->add_setting('slider_category',array(
			'default' => '1',
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'we_build_sanitize_integer'
	));

    $category_array = array(); 

	foreach ( get_categories() as $categories => $category ){
	    $category_array[$category->term_id] = $category->name;
	}

	$wp_customize->add_control('slider_category',array(
			'type' => 'select',
            'choices' => $category_array,
			'label'	=> __('Select a category for the featured post slider','we-build'),
			'section'	=> 'slider_section'
	));
	// Slider Section End	

    // Home Section Start		
	$wp_customize->add_section(
        'home_section',
        array(
            'title' => __('Home Settings', 'we-build'),
            'priority' => null,
			'description'	=> __('Manage Home Page Sections','we-build')
        )
    );	

    $wp_customize->add_setting('about_title', array(
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('about_title',array(
    'label' => __('Intro Title','we-build'),
    'section'   => 'home_section',
    'type'      => 'text'
    ));

    $wp_customize->add_setting('about_sub_title', array(
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('about_sub_title',array(
    'label' => __('Intro Sub Title','we-build'),
    'section'   => 'home_section',
    'type'      => 'text'
    ));
    $wp_customize->add_setting('about_readmore_link', array(
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('about_readmore_link',array(
    'label' => __('Intro Readmore Link','we-build'),
    'section'   => 'home_section',
    'type'      => 'text'
    ));

    $wp_customize->add_setting('service_title', array(
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('service_title',array(
    'label' => __('Service Title','we-build'),
    'section'   => 'home_section',
    'type'      => 'text'
    ));

    $wp_customize->add_setting('service_sub_title', array(
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('service_sub_title',array(
    'label' => __('Service Sub Title','we-build'),
    'section'   => 'home_section',
    'type'      => 'text'
    ));

    $wp_customize->add_setting('service_page_column1',	array(
			'default'	=> '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'absint'
	));
 
	$wp_customize->add_control(	'service_page_column1',array(
		    'label' => __('Select Service Pages','we-build'),
			'type' => 'dropdown-pages',
			'section' => 'home_section',
	));	
	
	$wp_customize->add_setting('service_page_column2',	array(
			'default'	=> '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'absint'
	));
 
	$wp_customize->add_control(	'service_page_column2',array(
			'type' => 'dropdown-pages',
			'section' => 'home_section',
	));
	
	$wp_customize->add_setting('service_page_column3',	array(
			'default'	=> '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'absint'
	));
 
	$wp_customize->add_control(	'service_page_column3',array(
			'type' => 'dropdown-pages',
			'section' => 'home_section',
	));
	$wp_customize->add_setting('service_page_column4',	array(
			'default'	=> '0',			
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'absint'
	));
 
	$wp_customize->add_control(	'service_page_column4',array(
			'type' => 'dropdown-pages',
			'section' => 'home_section',
	));

	$wp_customize->add_setting('blog_title', array(
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('blog_title',array(
    'label' => __('Blog Title','we-build'),
    'section'   => 'home_section',
    'type'      => 'text'
    ));

    $wp_customize->add_setting('blog_sub_title', array(
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('blog_sub_title',array(
    'label' => __('Blog Sub Title','we-build'),
    'section'   => 'home_section',
    'type'      => 'text'
    ));

    // Home end

    // Site Layout Section Start		
	$wp_customize->add_section(
        'layout_section',
        array(
            'title' => __('Layout Settings', 'we-build'),
            'priority' => null,
			'description'	=> __('Website Layout Options','we-build')
        )
    );

    $site_layout = array('pull-left' => __('Right Sidebar', 'we-build'),'pull-right' => __('Left Sidebar', 'we-build'));

    $wp_customize->add_setting('site_layout',array(
	'default' => 'pull-left',
	'capability' => 'edit_theme_options',
	'sanitize_callback'	=> 'sanitize_text_field',

    ));
    $wp_customize->add_control('site_layout',array(
    'type'      => 'select',
    'choices'   => $site_layout,
    'label' => __('Choose between Left and Right sidebar options to be used as default','we-build'),
    'section'   => 'layout_section'
    
    ));
    //End

	// Footer Section Start		
	$wp_customize->add_section(
        'footer_section',
        array(
            'title' => __('Footer Settings', 'we-build'),
            'priority' => null,
			'description'	=> __('Customize the site footer','we-build')
        )
    );

    $wp_customize->add_setting('footer_widget_color_scheme', array(
		'default' => '#313233',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'footer_widget_color_scheme',array(
			'label' => __('Footer Widget Area Background Color','we-build'),
			'section' => 'footer_section',
			'settings' => 'footer_widget_color_scheme'
		))
	);

	$wp_customize->add_setting('footer_copy_right_color_scheme', array(
		'default' => '#1F1F1F',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'footer_copy_right_color_scheme',array(
			'label' => __('Footer Copy Right Background Color','we-build'),
			'section' => 'footer_section',
			'settings' => 'footer_copy_right_color_scheme'
		))
	);

	$wp_customize->add_setting('footer_text_color_scheme', array(
		'default' => '#999',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'footer_text_color_scheme',array(
			'label' => __('Footer Text Color','we-build'),
			'section' => 'footer_section',
			'settings' => 'footer_text_color_scheme'
		))
	);

	$wp_customize->add_setting('footer_link_color_scheme', array(
		'default' => '#ffffff',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'footer_link_color_scheme',array(
			'label' => __('Footer Link Color','we-build'),
			'section' => 'footer_section',
			'settings' => 'footer_link_color_scheme'
		))
	);

    // Footer Section End

}
add_action( 'customize_register', 'we_build_customize_register' );

function we_build_sanitize_integer( $input ) {
	if( is_numeric( $input ) ) {
        return intval( $input );
    }
}

/**
 * Binds customizer css changes to the site.
 */

function we_build_customizer_css(){
		?>
        <style> 

                .label-default, .flex-caption h2, .dropdown-menu > li > a:hover, .dropdown-menu > li > a:focus, .navbar-default .navbar-nav .open .dropdown-menu > li > a:hover, .navbar-default .navbar-nav .open .dropdown-menu > li > a:focus,
                    .btn-default:hover,
                    .da-slide .da-link,
                    .da-slide .da-link:hover
                    {
                	background-color:<?php echo esc_html(get_theme_mod('site_main_color_scheme','#ff7761')); ?>;
        	        border-color:<?php echo esc_html(get_theme_mod('site_main_color_scheme','#ff7761')); ?>;
                }
                .top-link,
                .label-default[href]:hover, 
                .label-default[href]:focus, #infinite-handle span:hover, 
                .btn.btn-default.read-more:hover, 
                .btn-default:hover, .scroll-to-top:hover,
                .btn-default:focus, .btn-default:active, 
                .btn-default.active, .site-main [class*="navigation"] a:hover, 
                .more-link:hover, #image-navigation .nav-previous a:hover, 
                #image-navigation .nav-next a:hover,
                .da-dots span,
                .rounded-btn:hover,
                .service-inner i:hover{
                    background-color:<?php echo esc_html(get_theme_mod('site_main_color_scheme','#ff7761')); ?>;

                }
                .navbar-default .navbar-nav > .active > a, 
                .navbar-default .navbar-nav > .active > a:hover, 
                .navbar-default .navbar-nav > .active > a:focus, 
                .navbar-default .navbar-nav > li > a:hover, 
                .navbar-default .navbar-nav > li > a:focus, .navbar-default .navbar-nav > .open > a, 
                .navbar-default .navbar-nav > .open > a:hover, 
                .navbar-default .navbar-nav > .open > a:focus,
                .entry-meta .fa,
                #infinite-handle span,
                a:hover,a:active,#footer-area a:hover,
                h1, h2, h3, h4, h5, h6, .h1, .h2, .h3, .h4, .h5, .h6,a,
                .blog .blog-text a,.underline,.service-icon,
                .rounded-btn,.btn-default{ 
        	        color:<?php echo esc_html(get_theme_mod('site_main_color_scheme','ff7761')); ?>;
                }
                .service-inner .service-icon,
                .rounded-btn,
                .site-main [class*="navigation"] a,
                .more-link,.btn-default,
                .page-links a span{
                	border-color:<?php echo esc_html(get_theme_mod('site_main_color_scheme','#ff7761')); ?>;
                }
                .navbar > .container .navbar-brand{
                	color:#<?php echo get_header_textcolor(); ?>;

                }               
               
                #social .social-profile{
                	color:<?php echo esc_html(get_theme_mod('social_icon_color_scheme','#ffffff')); ?>;
                }
                #social .social-profile:hover {
                	color:<?php echo esc_html(get_theme_mod('social_icon_link_color_scheme','#fff')); ?>;
                }	
				.site-info a, #footer-area a{
					color:<?php echo esc_html(get_theme_mod('footer_link_color_scheme','#ffffff')); ?>;
				}
				#footer-area, .site-info{
					color:<?php echo esc_html(get_theme_mod('footer_text_color_scheme','#999')); ?>;
				}				
				#footer-area{
					background-color:<?php echo esc_html(get_theme_mod('footer_widget_color_scheme','#313233')); ?>;
				}
				#colophon{
					background-color:<?php echo esc_html(get_theme_mod('footer_copy_right_color_scheme','#1F1F1F')); ?>;
				}
		</style>
	<?php }
add_action('wp_head','we_build_customizer_css');


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function we_build_customize_preview_js() {
	wp_enqueue_script( 'we_build_customizer', get_template_directory_uri() . '/inc/js/customizer.js', array( 'customize-preview' ), '20170626', true );
}
add_action( 'customize_preview_init', 'we_build_customize_preview_js' );



