<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package We Build
 */

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 *
 * @param array $args Configuration arguments.
 * @return array
 */
 
 
 
/* index.php, single.php, search.php, archive.php -----------------------------*/
function we_build_post_before() { we_build_do_contextual_hook('we_build_post_before'); }
function we_build_post_after() { we_build_do_contextual_hook('we_build_post_after'); }
function we_build_post_start() { we_build_do_contextual_hook('we_build_post_start'); }
function we_build_post_end() { we_build_do_contextual_hook('we_build_post_end'); }

/* page.php -------------------------------------------------------------------*/
function we_build_page_before() { we_build_do_contextual_hook('we_build_page_before'); }
function we_build_page_after() { we_build_do_contextual_hook('we_build_page_after'); }
function we_build_page_start() { we_build_do_contextual_hook('we_build_page_start'); }
function we_build_page_end() { we_build_do_contextual_hook('we_build_page_end'); }

/* single.php, page.php, templates with comments ------------------------------*/
function we_build_comments_before() { we_build_do_contextual_hook('we_build_comments_before'); }
function we_build_comments_after() { we_build_do_contextual_hook('we_build_comments_after'); }

/* sidebar.php ----------------------------------------------------------------*/
function we_build_sidebar_before() { we_build_do_contextual_hook('we_build_sidebar_before'); }
function we_build_sidebar_after() { we_build_do_contextual_hook('we_build_sidebar_after'); }
function we_build_sidebar_start() { we_build_do_contextual_hook('we_build_sidebar_start'); }
function we_build_sidebar_end() { we_build_do_contextual_hook('we_build_sidebar_end'); }

/* footer.php -----------------------------------------------------------------*/
function we_build_content_end() { we_build_do_contextual_hook('we_build_content_end'); }
function we_build_footer_before() { we_build_do_contextual_hook('we_build_footer_before'); }
function we_build_footer_after() { we_build_do_contextual_hook('we_build_footer_after'); }
function we_build_footer_start() { we_build_do_contextual_hook('we_build_footer_start'); }
function we_build_footer_end() { we_build_do_contextual_hook('we_build_footer_end'); }
function we_build_body_end() { we_build_do_contextual_hook('we_build_body_end'); }
 
 
function we_build_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'we_build_page_menu_args' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function we_build_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	return $classes;
}
add_filter( 'body_class', 'we_build_body_classes' );

// Mark Posts/Pages as Untiled when no title is used
add_filter( 'the_title', 'we_build_title' );

function we_build_title( $title ) {
  if ( $title == '' ) {
    return __('Untitled', 'we-build');
  } else {
    return $title;
  }
}

/************* search form *****************/

// Search Form
function we_build_wpsearch($form) {
    $form = '<form method="get" class="form-search" action="' . home_url( '/' ) . '">
  <div class="row">
    <div class="col-lg-12">
      <div class="input-group">
        <input type="text" class="form-control search-query" value="' . get_search_query() . '" name="s" id="s" placeholder="'. esc_attr__('Search...','we-build') .'">
        <span class="input-group-btn">
          <button type="submit" class="btn btn-default" name="submit" id="searchsubmit" value="Go"><span class="glyphicon glyphicon-search"></span></button>
        </span>
      </div>
    </div>
  </div>
</form>';
    return $form;
} // don't remove this bracket!

/****************** password protected post form *****/

add_filter( 'the_password_form', 'we_build_custom_password_form' );

function we_build_custom_password_form() {
	global $post;
	$label = 'pwbox-'.( empty( $post->ID ) ? rand() : $post->ID );
	$o = '<form class="protected-post-form" action="' . get_option('siteurl') . '/wp-login.php?action=postpass" method="post">
  <div class="row">
    <div class="col-lg-10">
        ' . __( "<p>This post is password protected. To view it please enter your password below:</p>" ,'we-build') . '
        <label for="' . $label . '">' . __( "Password:" ,'we-build') . ' </label>
      <div class="input-group">
        <input class="form-control" value="' . get_search_query() . '" name="post_password" id="' . $label . '" type="password">
        <span class="input-group-btn"><button type="submit" class="btn btn-default" name="submit" id="searchsubmit" vvalue="' . esc_attr__( "Submit",'we-build' ) . '">' . __( "Submit" ,'we-build') . '</button>
        </span>
      </div>
    </div>
  </div>
</form>';
	return $o;
}

// Add Bootstrap classes for table
add_filter( 'the_content', 'we_build_add_custom_table_class' );
function we_build_add_custom_table_class( $content ) {
    return str_replace( '<table>', '<table class="table table-hover">', $content );
}

// //Display social links
function we_build_social(){
    $services = array ('facebook','twitter','googleplus','youtube');
    
    echo '<div id="social" class="social"><ul>';
    
    foreach ( $services as $service ) :
        
        $active[$service] = get_theme_mod ('social_'.$service);
        if ($active[$service]) { echo '<li><a class="social-profile" href="'.esc_url($active[$service]).'" class="social-icon '. $service .'" title="'. esc_attr__('Follow us on ','we-build').esc_html($service).'"><i class="social_icon fa fa-'.esc_attr($service).'"></i></a></li>';}
        
    endforeach;
    echo '</ul></div>';

}

// header menu (should you choose to use one)
function we_build_header_menu() {
        // display the WordPress Custom Menu if available
        wp_nav_menu(array(
                    'theme_location'    => 'primary',
                    'depth'             => 2,
                    'container'         => 'div',
                    'container_class'   => 'collapse navbar-collapse navbar-ex1-collapse',
                    'menu_class'        => 'nav navbar-nav main-nav',
                    'fallback_cb'       => 'wp_bootstrap_navwalker::fallback',
                    'walker'            => new wp_bootstrap_navwalker()
        ));
} /* end header menu */

function we_build_top_content() {
  // display the phone number and address
        echo '<div class="contact-info">';
        echo '<span class="contact-phone">';
        echo esc_html(get_theme_mod('header_phone'));
        echo '</span>';
        if(get_theme_mod('header_phone')&&get_theme_mod('header_address')){
          echo '|';  
        }  
        echo '<span class="contact-address">';
        echo esc_html(get_theme_mod('header_address'));
        echo '</span>';      
        echo '</div>';

} /* end */


//* adding top content and top solcialbar
function we_build_theme_topmenu_social() {
	 echo '<div class="top-link">' ?>
		<div  class="container">
			<div class="col-md-6">
			<?php we_build_top_content(); ?>
			</div>
			<div class="col-md-6 header-social">
			<?php we_build_social(); ?>
			</div>
		</div>
	</div>
  <div class="clear"></div>
<?php };
add_action('before', 'we_build_theme_topmenu_social');
// header images
function we_build_theme_headerimage() {
	 if( get_header_image() != '' ) : ?>
		<div id="headerimage">
		<img src="<?php header_image(); ?>"   alt="<?php bloginfo( 'name' ); ?>"/>
		</div>

				<?php endif; // header image was removed ?>

<?php };
add_action('before', 'we_build_theme_headerimage');

// Featured image slider 
function we_build_featured_slider() {
    if ( is_front_page() && (get_theme_mod('slider_show', 1) == 1) ) {	
      echo '<div id="myCarousel" class="carousel slide" data-ride="carousel">';    
      
          $count    = get_theme_mod('number_of_slides');
          $slidecat = get_theme_mod('slider_category');

          $query = new WP_Query( array( 'cat' =>$slidecat,'posts_per_page' =>$count ) );
          if ($query->have_posts()) :
            $count = $query->post_count;
            $i=0;
            echo ' <ol class="carousel-indicators">';

            for($c=0;$c<$count;$c++){
                if($c==0){
                  $active = 'active';
                }else{
                  $active = '';
                }
                echo '<li data-target="#myCarousel" data-slide-to="'.$c.'" class="'.$active.'"></li>';
            }
            echo '</ol>';       
            echo '<div class="carousel-inner">';
            while ($query->have_posts()) : $query->the_post();  
              if($i==0){
                $active = 'active';
              }else{
                $active = '';
              }
              echo '<div class="item '.$active.'">'; 
                      if ( has_post_thumbnail() ) {
                      echo get_the_post_thumbnail();
                      }else{
                        echo '<img src="'. esc_url( get_template_directory_uri()) . '/assets/images/slider1.jpg" alt="image" />';
                      }            
                      if ( get_the_title() != '' ) 
                        echo '<div class="carousel-caption">
                        <h1>'. get_the_title().'</h1>';
                        echo '<p>'; //echo the_excerpt(); 
                        echo esc_html( we_build_limit_words( get_the_excerpt(), 25 ) );echo '</p><a class="rounded-btn" href="'. esc_url(get_permalink()) .'">Read More</a></p>';						
              echo '</div>';	
            echo '</div>';
            $i++;
            endwhile;
            echo '</div>';
          endif;

				  echo '<a class="left carousel-control" href="#myCarousel" data-slide="prev">
               <span class="glyphicon glyphicon-chevron-left"></span>
               <span class="sr-only">Previous</span>
               </a>
               <a class="right carousel-control" href="#myCarousel" data-slide="next">
               <span class="glyphicon glyphicon-chevron-right"></span>
               <span class="sr-only">Next</span>
               </a>';
          echo '</div>';       
    } else {
      // Do nothing
    }
}

/**
 * function to show the footer info, copyright information
 */
function we_build_footer_info() {
global $we_build_footer_info;
  printf( esc_html__( 'Theme by %1$s Powered by %2$s', 'we-build' ) , '<a href="http://astaporthemes.com" target="_blank">Astapor Themes</a>', '<a href="http://wordpress.org/" target="_blank">WordPress</a>'); 
}